/*
 * pdf-presenter - advanced pdf presentation util
 *
 * Copyright (C) 2010-2012 Sebastian Reichel <sre@ring0.de>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

using Gtk;

class ConfigWindow : Dialog {
	Gtk.CheckButton fullscreen_control_window;
	Gtk.ComboBoxEntry monitor_control;
	Gtk.ComboBoxEntry monitor_presentation;

	public ConfigWindow() {
		title = "PDF Presentator (Config)";
		position = WindowPosition.CENTER;

		monitor_control = new Gtk.ComboBoxEntry.text();
		monitor_presentation = new Gtk.ComboBoxEntry.text();

		if(config.control_monitor != null && !(config.control_monitor in monitor.get_all()))
			monitor_control.append_text(config.control_monitor);
		if(config.presentation_monitor != null && !(config.presentation_monitor in monitor.get_all()))
			monitor_presentation.append_text(config.presentation_monitor);

		foreach(string s in monitor.get_all()) {
			monitor_control.append_text(s);
			monitor_presentation.append_text(s);
		}

		var table = new Gtk.Table(1,4,false);
		var content = this.get_content_area () as Gtk.Box;
		content.pack_start(table, false, true, 10);

		fullscreen_control_window = new Gtk.CheckButton.with_label("Fullscreen Configuration Window");
		table.attach(fullscreen_control_window, 0, 2, 0, 1, Gtk.AttachOptions.FILL, 0, 0, 0);

		table.attach(new Gtk.Label("Control Monitor"), 0, 1, 2, 3, Gtk.AttachOptions.FILL, 0, 0, 0);
		table.attach(monitor_control, 1, 2, 2, 3, 0, 0, 0, 0);

		table.attach(new Gtk.Label("Presentation Monitor"), 0, 1, 3, 4, Gtk.AttachOptions.FILL, 0, 0, 0);
		table.attach(monitor_presentation, 1, 2, 3, 4, 0, 0, 0, 0);
		// TODO: add keybinding configuration

		add_button(Stock.OK, ResponseType.OK);
		add_button(Stock.CANCEL, ResponseType.CANCEL);

		monitor.connected.connect(add_monitor);
		monitor.disconnected.connect(remove_monitor);

		/* set initial values */
		set_by_text(monitor_control, config.control_monitor);
		set_by_text(monitor_presentation, config.presentation_monitor);
		fullscreen_control_window.set_active(config.control_fullscreen);

		response.connect(response_handler);
		show_all();
	}

	private void set_by_text(Gtk.ComboBoxEntry box, string text) {
		var model = box.get_model();
		Gtk.TreeIter iter;
		Value val;
		int i = 0;
		
		if(!model.get_iter_first(out iter))
			return;

		do {
			model.get_value(iter, 0, out val);

			if(val.get_string() == text) {
				box.set_active(i);
				return;
			}

			i++;
		} while(model.iter_next(ref iter));
	}

	void add_monitor(string s) {
		monitor_control.append_text(s);
		monitor_presentation.append_text(s);
	}

	void remove_monitor(string s) {
		/* TODO */
	}

	void response_handler(int id) {
		monitor.connected.disconnect(add_monitor);
		monitor.disconnected.disconnect(remove_monitor);

		if(id == ResponseType.OK) {
			config.control_monitor = monitor_control.get_active_text();
			config.control_fullscreen = fullscreen_control_window.get_active();
			config.presentation_monitor = monitor_presentation.get_active_text();
			config.save();
			config.configuration_changed();
		}

		destroy();
	}
}
